==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/doc/TestChoiceWithSubstitutionGroup.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.ChoiceWithSubstitutionGroup;


/**
 * <p>Java class for testChoiceWithSubstitutionGroup element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testChoiceWithSubstitutionGroup">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types3}ChoiceWithSubstitutionGroup"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types3}ChoiceWithSubstitutionGroup"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testChoiceWithSubstitutionGroup")
public class TestChoiceWithSubstitutionGroup {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected ChoiceWithSubstitutionGroup x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected ChoiceWithSubstitutionGroup y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceWithSubstitutionGroup }
     *     
     */
    public ChoiceWithSubstitutionGroup getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceWithSubstitutionGroup }
     *     
     */
    public void setX(ChoiceWithSubstitutionGroup value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceWithSubstitutionGroup }
     *     
     */
    public ChoiceWithSubstitutionGroup getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceWithSubstitutionGroup }
     *     
     */
    public void setY(ChoiceWithSubstitutionGroup value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/doc/TestChoiceWithSubstitutionGroup.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.ChoiceWithSubstitutionGroup;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types3}ChoiceWithSubstitutionGroup"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types3}ChoiceWithSubstitutionGroup"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testChoiceWithSubstitutionGroup")
public class TestChoiceWithSubstitutionGroup {

    @XmlElement(required = true)
    protected ChoiceWithSubstitutionGroup x;
    @XmlElement(required = true)
    protected ChoiceWithSubstitutionGroup y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceWithSubstitutionGroup }
     *     
     */
    public ChoiceWithSubstitutionGroup getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceWithSubstitutionGroup }
     *     
     */
    public void setX(ChoiceWithSubstitutionGroup value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ChoiceWithSubstitutionGroup }
     *     
     */
    public ChoiceWithSubstitutionGroup getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChoiceWithSubstitutionGroup }
     *     
     */
    public void setY(ChoiceWithSubstitutionGroup value) {
        this.y = value;
    }

}
